Struct rust_tdlib::types::GetLoginUrl
source · [−]pub struct GetLoginUrl { /* private fields */ }Expand description
Returns an HTTP URL which can be used to automatically authorize the user on a website after clicking an inline button of type inlineKeyboardButtonTypeLoginUrl. Use the method getLoginUrlInfo to find whether a prior user confirmation is needed. If an error is returned, then the button must be handled as an ordinary URL button
Implementations