Struct rust_tdlib::types::RegisterDevice
source · [−]pub struct RegisterDevice { /* private fields */ }Expand description
Registers the currently used device for receiving push notifications. Returns a globally unique identifier of the push notification subscription
Implementations
sourceimpl RegisterDevice
impl RegisterDevice
pub fn from_json<S: AsRef<str>>(json: S) -> Result<Self>
pub fn builder() -> RegisterDeviceBuilder
pub fn device_token(&self) -> &DeviceToken
pub fn other_user_ids(&self) -> &Vec<i64>