Struct rust_tdlib::types::SharePhoneNumber
source · [−]pub struct SharePhoneNumber { /* private fields */ }Expand description
Shares the phone number of the current user with a mutual contact. Supposed to be called when the user clicks on chatActionBarSharePhoneNumber
Implementations