pub trait TDBotCommandScope: Debug + RObject { }Expand description
Represents the scope to which bot commands are relevant
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TDBotCommandScope: Debug + RObject { }Represents the scope to which bot commands are relevant
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".