pub trait TDCallProblem: Debug + RObject { }Expand description
Describes the exact type of a problem with a call
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TDCallProblem: Debug + RObject { }Describes the exact type of a problem with a call
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".