pub trait TDChatSource: Debug + RObject { }Expand description
Describes a reason why an external chat is shown in a chat list
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TDChatSource: Debug + RObject { }Describes a reason why an external chat is shown in a chat list
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".