pub trait TDLanguagePackStringValue: Debug + RObject { }Expand description
Represents the value of a string in a language pack
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TDLanguagePackStringValue: Debug + RObject { }Represents the value of a string in a language pack
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".