pub trait TDMaskPoint: Debug + RObject { }Expand description
Part of the face, relative to which a mask is placed
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TDMaskPoint: Debug + RObject { }Part of the face, relative to which a mask is placed
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".