pub trait TDPageBlock: Debug + RObject { }Expand description
Describes a block of an instant view web page
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait TDPageBlock: Debug + RObject { }Describes a block of an instant view web page
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".