TDReplyMarkup

Trait TDReplyMarkup 

pub trait TDReplyMarkup: Debug + RObject { }
Contains a description of a custom keyboard and actions that can be done with it to quickly reply to bots

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, REPLYMARKUP: TDReplyMarkup> TDReplyMarkup for &'a REPLYMARKUP

Source

impl<'a, REPLYMARKUP: TDReplyMarkup> TDReplyMarkup for &'a mut REPLYMARKUP

Implementors